@@ -463,9 +463,9 @@ class RefreshThread(threading.Thread):
             wTree.get_widget("vpaned1").set_position(vpaned_position)
             gtk.gdk.threads_leave()
             if app_hidden:
-                updates = commands.getoutput("/usr/lib/linuxmint/mintUpdate/checkAPT.py | grep \"###\"")
+                updates = commands.getoutput("sudo /usr/lib/linuxmint/mintUpdate/checkAPT.py | grep \"###\"")
             else:
-                updates = commands.getoutput("/usr/lib/linuxmint/mintUpdate/checkAPT.py --use-synaptic %s | grep \"###\"" % self.wTree.get_widget("window1").window.xid)
+                updates = commands.getoutput("sudo /usr/lib/linuxmint/mintUpdate/checkAPT.py --use-synaptic %s | grep \"###\"" % self.wTree.get_widget("window1").window.xid)
            
             # Look for mintupdate
             if ("UPDATE###mintupdate###" in updates):                
@@ -978,7 +978,9 @@ def read_configuration():
     return prefs
 
 def open_repositories(widget):
-    if os.path.exists("/usr/bin/software-properties-gtk"):
+    if os.path.exists("/usr/bin/software-sources"):
+        os.system("/usr/bin/software-sources &")
+    elif os.path.exists("/usr/bin/software-properties-gtk"):
         os.system("/usr/bin/software-properties-gtk &")
     elif os.path.exists("/usr/bin/software-properties-kde"):
         os.system("/usr/bin/software-properties-kde &")
@@ -1617,7 +1619,7 @@ try:
     prefsMenuItem.get_child().set_text(_("Preferences"))
     prefsMenuItem.connect("activate", open_preferences, treeview_update, statusIcon, wTree)
     editSubmenu.append(prefsMenuItem)
-    if os.path.exists("/usr/bin/software-properties-gtk") or os.path.exists("/usr/bin/software-properties-kde"):
+    if os.path.exists("/usr/bin/software-sources") or os.path.exists("/usr/bin/software-properties-gtk") or os.path.exists("/usr/bin/software-properties-kde"):
         sourcesMenuItem = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
         sourcesMenuItem.set_image(gtk.image_new_from_file("/usr/lib/linuxmint/mintUpdate/icons/software-properties.png"))
         sourcesMenuItem.get_child().set_text(_("Software sources"))
@@ -1704,23 +1706,13 @@ try:
         #test the network connection to delay mintUpdate in case we're not yet connected
         log.writelines("++ Testing initial connection\n")
         log.flush()
-        try:
-            from urllib import urlopen
-            url=urlopen("http://google.com")
-            url.read()
-            url.close()
-            log.writelines("++ Connection to the Internet successful (tried to read http://www.google.com)\n")
+        if os.system("ping " + prefs["ping_domain"] + " -c1 -q"):
+            log.writelines("-- No connection found (tried to ping " + prefs["ping_domain"] + ") - sleeping for " + str(prefs["delay"]) + " seconds\n")
+            log.flush()
+            time.sleep(prefs["delay"])
+        else:
+            log.writelines("++ Connection found - checking for updates\n")
             log.flush()
-        except Exception, detail:
-            print detail
-            if os.system("ping " + prefs["ping_domain"] + " -c1 -q"):
-                log.writelines("-- No connection found (tried to read http://www.google.com and to ping " + prefs["ping_domain"] + ") - sleeping for " + str(prefs["delay"]) + " seconds\n")
-                log.flush()
-                time.sleep(prefs["delay"])
-            else:
-                log.writelines("++ Connection found - checking for updates\n")
-                log.flush()
-
 
     wTree.get_widget("notebook_details").set_current_page(0)
 
